 /*
 * FILE --- veh_sim_pid.hh
 *
 * PURPOSE --- To rpovide an example use of the class for 4'th
 * order Runge-Kutta simulation, RK4_SIM.
 * Header file contains class for performing a simulation of
 * a simple vehicle with point mass dynamics.
 *
 */

// Prevent Multiple Inclusion
#ifndef VEH_SIM_PID_HH
#define VEH_SIM_PID_HH

// Include Files
#include <math.h>
#include "rk4_sim.hh"
#include "pid_ctrl.hh"

// Local Definitions and macros
#define RIGHT_LANE -1
#define LEFT_LANE 1

class VEH_SIM_PID : public RK4_SIM
{
public:
  VEH_SIM_PID (double samp_time = 0.005, int _simulation_per_cycle = 10,
	       double _initial_time = 0.0, double *_initial_state = NULL);
  ~VEH_SIM_PID ();

private:
  // Plant parameters
  double mass;
  double drag_x;
  //  double drag_y;
  double tau;
  double disturbance;
  PID_CTRL *pid_ctrl;

public:
  double sampling_period;
  int simulation_per_cycle; // # of RK4 simulations per sampling interval

  // Overload DERIV function of RK4_SIM for simulating vehicle dynamics
  inline void DERIV(const double t, const double *x, 
		    const double *u, double *xdot);
  
  // the Simulation routine
  void simulate ();
};

#endif // VEH_SIM_PID_HH
